@@ -14,10 +14,10 @@ class Provider(Enum):
 
     def __call__(self, *args, **kwargs):
         return {
-            Provider.ESKOM: eskom.Eskom(*args, **kwargs),
-            Provider.COCT: coct.CoCT(*args, **kwargs),
-            Provider.SE_PUSH: sepush.SePush(*args, **kwargs),
-        }.get(self, None)
+            Provider.ESKOM: eskom.Eskom,
+            Provider.COCT: coct.CoCT,
+            Provider.SE_PUSH: sepush.SePush,
+        }.get(self, None)(*args, **kwargs)
 
     def __str__(self):
         return {
