@@ -13,7 +13,6 @@
 #
 #      You should have received a copy of the GNU General Public License
 #      along with this program.  If not, see <https://www.gnu.org/licenses/>.
-import http
 import json
 from typing import Any, Dict, List
 
@@ -30,19 +29,19 @@ CITY_OF_CAPE_TOWN = "capetown"
 
 
 class SePush:
-    base_url = "https://us-central1-sepush-app.cloudfunctions.net/sepush-serverless-business-api-staging-http/business/2.0"
+    base_url = "https://developer.sepush.co.za/business/2.0"
     token = ""
 
     def __init__(self, token=None):
         if token:
             self.token = token
 
-    def areas_search(self, text: str) -> List[Dict]:
+    def areas_search(self, text: str) -> Dict:
         url = f"{self.base_url}/areas_search?text={text}"
         data = _call(url, self.token)
         return json.loads(data)
 
-    def area(self, area_id: str) -> List[Dict]:
+    def area(self, area_id: str) -> Dict:
         url = f"{self.base_url}/area?id={area_id}"
         data = _call(url, self.token)
         return json.loads(data)
@@ -52,7 +51,7 @@ class SePush:
         data = _call(url, self.token)
         return json.loads(data)
 
-    def status(self) -> int:
+    def status(self) -> Dict:
         url = f"{self.base_url}/status"
         data = _call(url, self.token)
         return json.loads(data)
@@ -70,4 +69,4 @@ def _call(url: str, token: str) -> Any:
             return r.data
     except Exception as e:
         error = json.loads(r.data).get("error")
-        raise SePushError(error, r.status, r.reason) from e
+        raise SePushError(error) from e
