@@ -33,7 +33,7 @@ class Area(Area):
 class Eskom(Provider):
     name = "Eskom Direct"
 
-    def __init__(self) -> object:
+    def __init__(self, *args, **kwargs) -> object:
         self.api = eskom.LoadShedding()
 
     def get_areas(self, search_text: str = None, max_results: int = None) -> List[Area]:
@@ -54,7 +54,7 @@ class Eskom(Provider):
             area_schedule = to_utc(area_schedule)
             return area_schedule
 
-    def get_stage(self) -> Stage:
+    def get_stage(self, coct_stage: bool = False) -> Stage:
         try:
             status = self.api.get_status()
         except Exception as e:
